Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CmdAddArgs ¶
type CmdAddArgs struct {
// container ID
// Required: true
ContainerID *string `json:"containerID"`
// if name
// Required: true
IfName *string `json:"ifName"`
// ipv4 pools
IPV4Pools []string `json:"ipv4Pools"`
// ipv6 pools
IPV6Pools []string `json:"ipv6Pools"`
// pod name
// Required: true
PodName *string `json:"podName"`
// pod namespace
// Required: true
PodNamespace *string `json:"podNamespace"`
}
CmdAddArgs cmd add args
swagger:model CmdAddArgs
func (*CmdAddArgs) ContextValidate ¶
ContextValidate validates this cmd add args based on context it is used
func (*CmdAddArgs) MarshalBinary ¶
func (m *CmdAddArgs) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CmdAddArgs) UnmarshalBinary ¶
func (m *CmdAddArgs) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type CmdAddResult ¶
type CmdAddResult struct {
// dns
DNS *DNS `json:"dns,omitempty"`
// ips
// Required: true
Ips []*IPConfig `json:"ips"`
// routes
Routes []*Route `json:"routes"`
}
CmdAddResult cmd add result
swagger:model CmdAddResult
func (*CmdAddResult) ContextValidate ¶
ContextValidate validate this cmd add result based on the context it is used
func (*CmdAddResult) MarshalBinary ¶
func (m *CmdAddResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CmdAddResult) UnmarshalBinary ¶
func (m *CmdAddResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type CmdDelArgs ¶
type CmdDelArgs struct {
// container ID
// Required: true
ContainerID *string `json:"containerID"`
// if name
// Required: true
IfName *string `json:"ifName"`
// pod name
// Required: true
PodName *string `json:"podName"`
// pod namespace
// Required: true
PodNamespace *string `json:"podNamespace"`
}
CmdDelArgs cmd del args
swagger:model CmdDelArgs
func (*CmdDelArgs) ContextValidate ¶
ContextValidate validates this cmd del args based on context it is used
func (*CmdDelArgs) MarshalBinary ¶
func (m *CmdDelArgs) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CmdDelArgs) UnmarshalBinary ¶
func (m *CmdDelArgs) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type DNS ¶
type DNS struct {
// domain
Domain string `json:"domain,omitempty"`
// nameservers
// Required: true
Nameservers []string `json:"nameservers"`
// options
Options []string `json:"options"`
// search
Search []string `json:"search"`
}
DNS DNS
swagger:model DNS
func (*DNS) ContextValidate ¶
ContextValidate validates this DNS based on context it is used
func (*DNS) MarshalBinary ¶
MarshalBinary interface implementation
func (*DNS) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Error ¶
type Error string
Error error
swagger:model Error
func (Error) ContextValidate ¶
ContextValidate validates this error based on context it is used
type IPConfig ¶
type IPConfig struct {
// address
// Required: true
Address *string `json:"address"`
// gateway
Gateway string `json:"gateway,omitempty"`
}
IPConfig IP config
swagger:model IPConfig
func (*IPConfig) ContextValidate ¶
ContextValidate validates this IP config based on context it is used
func (*IPConfig) MarshalBinary ¶
MarshalBinary interface implementation
func (*IPConfig) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Route ¶
type Route struct {
// dst
// Required: true
Dst *string `json:"dst"`
// gw
Gw string `json:"gw,omitempty"`
}
Route route
swagger:model Route
func (*Route) ContextValidate ¶
ContextValidate validates this route based on context it is used
func (*Route) MarshalBinary ¶
MarshalBinary interface implementation
func (*Route) UnmarshalBinary ¶
UnmarshalBinary interface implementation